import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_cloudtrail._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_efs._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_lambda_destinations._jsii
import aws_cdk.aws_lambda_event_sources._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_sqs._jsii
import aws_cdk.core._jsii
import cdk_nag._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-serverless-clamscan",
    "1.1.59",
    __name__[0:-6],
    "cdk-serverless-clamscan@1.1.59.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
